# OARepo model builder drafts

Plugin replacing the original uploading process with a one saving records into
drafts and publishing them when necessary.

Based on InvenioRDM process, for api documentation see the InvenioRDM [docs](https://inveniordm.docs.cern.ch/reference/rest_api_drafts_records/).